@@ -182,15 +182,15 @@ def get_text_v3(address, stream, mapped=False, decode=True):
         return "" if decode else b""
 
     if mapped:
-        block_id = stream[address: address+2]
-        if block_id != b'TX':
+        block_id = stream[address : address + 2]
+        if block_id != b"TX":
             return "" if decode else b""
         (size,) = UINT16_uf(stream, address + 2)
         text_bytes = stream[address + 4 : address + size].strip(b" \r\t\n\0")
     else:
         stream.seek(address)
         block_id = stream.read(2)
-        if block_id != b'TX':
+        if block_id != b"TX":
             return "" if decode else b""
         size = UINT16_u(stream.read(2))[0] - 4
         text_bytes = stream.read(size).strip(b" \r\t\n\0")
@@ -227,15 +227,15 @@ def get_text_v4(address, stream, mapped=False, decode=True):
         return "" if decode else b""
 
     if mapped:
-        block_id = stream[address: address+4]
-        if block_id not in (b'##TX', b'##MD'):
+        block_id = stream[address : address + 4]
+        if block_id not in (b"##TX", b"##MD"):
             return "" if decode else b""
         (size,) = UINT64_uf(stream, address + 8)
         text_bytes = stream[address + 24 : address + size].strip(b" \r\t\n\0")
     else:
         stream.seek(address)
         block_id = stream.read(8)[:4]
-        if block_id not in (b'##TX', b'##MD'):
+        if block_id not in (b"##TX", b"##MD"):
             return "" if decode else b""
         size, _ = TWO_UINT64_u(stream.read(16))
         text_bytes = stream.read(size - 24).strip(b" \r\t\n\0")
@@ -359,7 +359,11 @@ def get_fmt_v4(data_type, size, channel_type=v4c.CHANNEL_TYPE_VALUE):
     if data_type in v4c.NON_SCALAR_TYPES:
         size = size // 8
 
-        if data_type in (v4c.DATA_TYPE_BYTEARRAY, v4c.DATA_TYPE_MIME_STREAM, v4c.DATA_TYPE_MIME_SAMPLE):
+        if data_type in (
+            v4c.DATA_TYPE_BYTEARRAY,
+            v4c.DATA_TYPE_MIME_STREAM,
+            v4c.DATA_TYPE_MIME_SAMPLE,
+        ):
             if channel_type == v4c.CHANNEL_TYPE_VALUE:
                 fmt = f"({size},)u1"
             else:
@@ -540,24 +544,24 @@ def fmt_to_datatype_v4(fmt, shape, array=False):
     size = fmt.itemsize * 8
     kind = fmt.kind
 
-    if not array and shape[1:] and fmt.itemsize == 1 and kind == "u":
+    if not array and len(shape) > 1 and size == 8 and kind == "u":
         data_type = v4c.DATA_TYPE_BYTEARRAY
         for dim in shape[1:]:
             size *= dim
 
     else:
         if kind == "u":
-            if byteorder in "<":
+            if byteorder == "<":
                 data_type = v4c.DATA_TYPE_UNSIGNED_INTEL
             else:
                 data_type = v4c.DATA_TYPE_UNSIGNED_MOTOROLA
         elif kind == "i":
-            if byteorder in "<":
+            if byteorder == "<":
                 data_type = v4c.DATA_TYPE_SIGNED_INTEL
             else:
                 data_type = v4c.DATA_TYPE_SIGNED_MOTOROLA
         elif kind == "f":
-            if byteorder in "<":
+            if byteorder == "<":
                 data_type = v4c.DATA_TYPE_REAL_INTEL
             else:
                 data_type = v4c.DATA_TYPE_REAL_MOTOROLA
@@ -567,7 +571,7 @@ def fmt_to_datatype_v4(fmt, shape, array=False):
             data_type = v4c.DATA_TYPE_UNSIGNED_INTEL
             size = 1
         elif kind == "c":
-            if byteorder in "<":
+            if byteorder == "<":
                 data_type = v4c.DATA_TYPE_COMPLEX_INTEL
             else:
                 data_type = v4c.DATA_TYPE_COMPLEX_MOTOROLA
@@ -995,6 +999,7 @@ class Group:
         self.channels = []
         self.channel_dependencies = []
         self.signal_data = []
+        self.signal_data_size = []
         self.parents = None
         self.types = None
         self.record = None
@@ -1022,6 +1027,7 @@ class Group:
         self.channels.clear()
         self.channel_dependencies.clear()
         self.signal_data.clear()
+        self.signal_data_size.clear()
 
 
 class VirtualChannelGroup:
@@ -1085,8 +1091,8 @@ def components(
 
     Returns
     -------
-    name, series : (str, pandas.Series)
-        tuple of unqiue name and Series object
+    name, series : (str, values)
+        tuple of unique name and values
     """
     names = channel.dtype.names
 
@@ -1104,8 +1110,17 @@ def components(
 
         values = channel[name]
         if len(values.shape) > 1:
-            values = list(values)
-        yield name_, Series(values, index=master)
+            values = Series(
+                list(values),
+                index=master,
+            )
+        else:
+            values = Series(
+                values,
+                index=master,
+            )
+
+        yield name_, values
 
         for name in names[1:]:
             values = channel[name]
@@ -1116,10 +1131,18 @@ def components(
             if len(values.shape) > 1:
                 arr = [values]
                 types = [("", values.dtype, values.shape[1:])]
-                values = fromarrays(arr, dtype=types)
+                values = Series(
+                    fromarrays(arr, dtype=types),
+                    index=master,
+                )
                 del arr
+            else:
+                values = Series(
+                    values,
+                    index=master,
+                )
 
-            yield axis_name, Series(values, index=master, dtype="O")
+            yield axis_name, values
 
     # structure composition
     else:
@@ -1147,9 +1170,17 @@ def components(
                 else:
                     name_ = unique_names.get_unique_name(name)
                 if len(values.shape) > 1:
-                    values = list(values)
+                    values = Series(
+                        list(values),
+                        index=master,
+                    )
+                else:
+                    values = Series(
+                        values,
+                        index=master,
+                    )
 
-                yield name_, Series(values, index=master)
+                yield name_, values
 
 
 class DataBlockInfo:
@@ -1348,257 +1379,6 @@ def master_using_raster(mdf, raster, endpoint=False):
     return master
 
 
-def extract_signal(signal, payload):
-    vals = payload
-
-    big_endian = False if signal.is_little_endian else True
-    signed = signal.is_signed
-
-    start_bit = signal.get_startbit(bit_numbering=1)
-
-    if big_endian:
-        start_byte = start_bit // 8
-        bit_count = signal.size
-
-        pos = start_bit % 8 + 1
-
-        over = bit_count % 8
-
-        if pos >= over:
-            bit_offset = (pos - over) % 8
-        else:
-            bit_offset = pos + 8 - over
-    else:
-        start_byte, bit_offset = divmod(start_bit, 8)
-
-    bit_count = signal.size
-
-    if big_endian:
-        byte_pos = start_byte + 1
-        start_pos = start_bit
-        bits = bit_count
-
-        while True:
-            pos = start_pos % 8 + 1
-            if pos < bits:
-                byte_pos += 1
-                bits -= pos
-                start_pos = 7
-            else:
-                break
-
-        if byte_pos > vals.shape[1]:
-            raise MdfException(
-                f'Could not extract signal "{signal.name}" with start '
-                f"bit {start_bit} and bit count {signal.size} "
-                f"from the payload with shape {vals.shape}"
-            )
-    else:
-        if start_bit + bit_count > vals.shape[1] * 8:
-            raise MdfException(
-                f'Could not extract signal "{signal.name}" with start '
-                f"bit {start_bit} and bit count {signal.size} "
-                f"from the payload with shape {vals.shape}"
-            )
-
-    byte_size, r = divmod(bit_offset + bit_count, 8)
-    if r:
-        byte_size += 1
-
-    if byte_size in (1, 2, 4, 8):
-        extra_bytes = 0
-    else:
-        extra_bytes = 4 - (byte_size % 4)
-
-    std_size = byte_size + extra_bytes
-
-    # prepend or append extra bytes columns
-    # to get a standard size number of bytes
-
-    # print(signal.name, start_bit, bit_offset, start_byte, byte_size)
-
-    if extra_bytes:
-        if big_endian:
-
-            vals = np.column_stack(
-                [
-                    vals[:, start_byte : start_byte + byte_size],
-                    np.zeros(len(vals), dtype=f"<({extra_bytes},)u1"),
-                ]
-            )
-
-            try:
-                vals = vals.view(f">u{std_size}").ravel()
-            except:
-                vals = np.frombuffer(vals.tobytes(), dtype=f">u{std_size}")
-
-            vals = vals >> (extra_bytes * 8 + bit_offset)
-            vals &= (2 ** bit_count) - 1
-
-        else:
-            vals = np.column_stack(
-                [
-                    vals[:, start_byte : start_byte + byte_size],
-                    np.zeros(len(vals), dtype=f"<({extra_bytes},)u1"),
-                ]
-            )
-            try:
-                vals = vals.view(f"<u{std_size}").ravel()
-            except:
-                vals = np.frombuffer(vals.tobytes(), dtype=f"<u{std_size}")
-
-            vals = vals >> bit_offset
-            vals &= (2 ** bit_count) - 1
-
-    else:
-        if big_endian:
-            try:
-                vals = (
-                    vals[:, start_byte : start_byte + byte_size]
-                    .view(f">u{std_size}")
-                    .ravel()
-                )
-            except:
-                vals = np.frombuffer(
-                    vals[:, start_byte : start_byte + byte_size].tobytes(),
-                    dtype=f">u{std_size}",
-                )
-
-            vals = vals >> bit_offset
-            vals &= (2 ** bit_count) - 1
-        else:
-            try:
-                vals = (
-                    vals[:, start_byte : start_byte + byte_size]
-                    .view(f"<u{std_size}")
-                    .ravel()
-                )
-            except:
-                vals = np.frombuffer(
-                    vals[:, start_byte : start_byte + byte_size].tobytes(),
-                    dtype=f"<u{std_size}",
-                )
-
-            vals = vals >> bit_offset
-            vals &= (2 ** bit_count) - 1
-
-    if signed:
-        vals = as_non_byte_sized_signed_int(vals, bit_count)
-
-    if (signal.factor, signal.offset) != (1, 0):
-        vals = vals * float(signal.factor)
-        vals += float(signal.offset)
-
-    return vals
-
-
-def extract_can_signal(signal, payload):
-    return extract_signal(signal, payload)
-
-
-def extract_mux(payload, message, message_id, bus, t, muxer=None, muxer_values=None):
-    """ extract multiplexed CAN signals from the raw payload
-
-    Parameters
-    ----------
-    payload : np.ndarray
-        raw CAN payload as numpy array
-    message : canmatrix.Frame
-        CAN message description parsed by canmatrix
-    message_id : int
-        message id
-    bus : int
-        bus channel number
-    t : np.ndarray
-        timestamps for the raw payload
-    muxer (None): str
-        name of the parent multiplexor signal
-    muxer_values (None): np.ndarray
-        multiplexor signal values
-
-    Returns
-    -------
-    extracted_signal : dict
-        each value in the dict is a list of signals that share the same
-        multiplexors
-
-    """
-    if muxer is None:
-        if message.is_multiplexed:
-            for sig in message:
-                if sig.multiplex == "Multiplexor" and sig.muxer_for_signal is None:
-                    multiplexor_name = sig.name
-                    break
-            for sig in message:
-                if (
-                    sig.multiplex not in (None, "Multiplexor")
-                    and sig.muxer_for_signal is None
-                ):
-                    sig.muxer_for_signal = multiplexor_name
-                    sig.mux_val_min = sig.mux_val_max = int(sig.multiplex)
-                    sig.mux_val_grp.insert(0, (int(sig.multiplex), int(sig.multiplex)))
-
-    extracted_signals = {}
-
-    if message.size > payload.shape[1]:
-        return extracted_signals
-
-    pairs = {}
-    for signal in message:
-        if signal.muxer_for_signal == muxer:
-            try:
-                entry = signal.mux_val_min, signal.mux_val_max
-            except:
-                entry = tuple(signal.mux_val_grp[0]) if signal.mux_val_grp else (0, 0)
-            pair_signals = pairs.setdefault(entry, [])
-            pair_signals.append(signal)
-
-    for pair, pair_signals in pairs.items():
-        entry = bus, message_id, muxer, *pair
-
-        extracted_signals[entry] = signals = {}
-
-        if muxer_values is not None:
-            min_, max_ = pair
-            idx = np.argwhere((min_ <= muxer_values) & (muxer_values <= max_)).ravel()
-            payload_ = payload[idx]
-            t_ = t[idx]
-        else:
-            t_ = t
-            payload_ = payload
-
-        for sig in pair_signals:
-            samples = extract_signal(sig, payload_)
-            if len(samples) == 0 and len(t_):
-                continue
-
-            max_val = np.full(len(samples), float(sig.calc_max()))
-
-            signals[sig.name] = {
-                "name": sig.name,
-                "comment": sig.comment or "",
-                "unit": sig.unit or "",
-                "samples": samples,
-                "t": t_,
-                "invalidation_bits": np.isclose(samples, max_val),
-            }
-
-            if sig.multiplex == "Multiplexor":
-                extracted_signals.update(
-                    extract_mux(
-                        payload_,
-                        message,
-                        message_id,
-                        bus,
-                        t_,
-                        muxer=sig.name,
-                        muxer_values=samples,
-                    )
-                )
-
-    return extracted_signals
-
-
 def csv_int2hex(val):
     """ format CAN id as hex
 
@@ -1708,7 +1488,7 @@ def all_blocks_addresses(obj):
     blocks = {}
 
     for match in re.finditer(pattern, source):
-        btype = match.group('block')
+        btype = match.group("block")
         start = match.start()
 
         btype_addresses = blocks.setdefault(btype, [])
@@ -1716,3 +1496,43 @@ def all_blocks_addresses(obj):
         addresses.append(start)
 
     return blocks, addresses
+
+
+def plausible_timestamps(t, minimum, maximum, exp_min=-15, exp_max=15):
+    """ check if the time stamps are plausible
+
+    Parameters
+    ----------
+    t : np.array
+        time stamps array
+    minimum : float
+        minimum plausible time stamp
+    maximum : float
+        maximum plausible time stamp
+    exp_min (-15) : int
+        minimum plausible exponent used for the time stamps float values
+    exp_max (15) : int
+        maximum plausible exponent used for the time stamps float values
+
+    Returns
+    -------
+    all_ok, idx : (bool, np.array)
+        the *all_ok* flag to indicate if all the time stamps are ok; this can be checked
+        before aopplying the indexing array.
+    """
+
+    exps = np.log10(t)
+    idx = (
+        (~np.isnan(t))
+        & (~np.isinf(t))
+        & (t >= minimum)
+        & (t <= maximum)
+        & (exps >= exp_min)
+        & (exps <= exp_max)
+    )
+    if not np.all(idx):
+        all_ok = False
+        return all_ok, idx
+    else:
+        all_ok = True
+        return all_ok, idx
