@@ -151,6 +151,7 @@ TABULAR_CONVERSIONS = {
     CONVERSION_TYPE_TABX,
     CONVERSION_TYPE_RTABX,
     CONVERSION_TYPE_TTAB,
+    CONVERSION_TYPE_BITFIELD,
 }
 
 CONVERSIONS_WITH_TEXTS = {
@@ -159,6 +160,7 @@ CONVERSIONS_WITH_TEXTS = {
     CONVERSION_TYPE_TABX,
     CONVERSION_TYPE_TRANS,
     CONVERSION_TYPE_TTAB,
+    CONVERSION_TYPE_BITFIELD,
 }
 
 CONVERSION_GROUP_1 = {CONVERSION_TYPE_NON, CONVERSION_TYPE_TRANS, CONVERSION_TYPE_TTAB}
@@ -333,6 +335,12 @@ FLAG_CG_TO_STRING = {
     FLAG_CG_EVENT_GROUP: "EVENT_GROUP",
 }
 
+FLAG_AT_TO_STRING = {
+    FLAG_AT_EMBEDDED: "Embedded",
+    FLAG_AT_COMPRESSED_EMBEDDED: "Compressed",
+    FLAG_AT_MD5_VALID: "MD5 sum valid",
+}
+
 FLAG_CN_ALL_INVALID = 1
 FLAG_CN_INVALIDATION_PRESENT = 1 << 1
 FLAG_CN_PRECISION = 1 << 2
@@ -727,7 +735,7 @@ KEYS_HL_BLOCK = (
     "reserved1",
 )
 
-FMT_EVENT_PARAMS = "<5B3sI2HQd"
+FMT_EVENT_PARAMS = "<5B3sI2Hqd"
 FMT_EVENT = "<4sI2Q{}Q5B3sI2Hqd"
 
 FMT_SR_BLOCK = "<4sI5Qd2B6s"
