@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from datetime import timedelta
+
 import numpy as np
 import pyqtgraph as pg
 
@@ -66,16 +67,10 @@ class FormatedAxis(pg.AxisItem):
                     else:
                         val = ""
                     strns.append(val)
-            elif self.format == 'time':
-                strns = [
-                    str(timedelta(seconds=val))
-                    for val in values
-                ]
-            elif self.format == 'date':
-                strns = [
-                    str(self.origin + timedelta(seconds=val))
-                    for val in values
-                ]
+            elif self.format == "time":
+                strns = [str(timedelta(seconds=val)) for val in values]
+            elif self.format == "date":
+                strns = [str(self.origin + timedelta(seconds=val)) for val in values]
 
         return strns
 
@@ -100,3 +95,11 @@ class FormatedAxis(pg.AxisItem):
         self._adjustSize()
         self.picture = None
         self.update()
+
+    def mouseDragEvent(self, event):
+        if self.linkedView() is None:
+            return
+        if self.orientation in ["left", "right"]:
+            return self.linkedView().mouseDragEvent(event)
+        else:
+            return self.linkedView().mouseDragEvent(event)
