@@ -15,6 +15,7 @@ class ListWidget(QtWidgets.QListWidget):
     items_rearranged = QtCore.pyqtSignal()
     add_channels_request = QtCore.pyqtSignal(list)
     show_properties = QtCore.pyqtSignal(object)
+    insert_computation = QtCore.pyqtSignal(str)
 
     def __init__(self, *args, **kwargs):
 
@@ -128,7 +129,7 @@ class ListWidget(QtWidgets.QListWidget):
 
             data.append(
                 pack(
-                    f"<36s3q{len(info)}s",
+                    f"<12s3q{len(info)}s",
                     str(item.mdf_uuid).encode("ascii"),
                     entry[0],
                     entry[1],
@@ -186,6 +187,8 @@ class ListWidget(QtWidgets.QListWidget):
         menu.addAction(self.tr("Relative time base shift"))
         menu.addAction(self.tr("Set time base start offset"))
         menu.addSeparator()
+        menu.addAction(self.tr("Insert computation using this channel"))
+        menu.addSeparator()
         menu.addAction(self.tr("Delete (Del)"))
         menu.addSeparator()
         menu.addAction(self.tr("File properties"))
@@ -326,10 +329,17 @@ class ListWidget(QtWidgets.QListWidget):
                 item = selected_items[0]
                 self.show_properties.emit(self.itemWidget(item).uuid)
 
+        elif action.text() == "Insert computation using this channel":
+            selected_items = self.selectedItems()
+            if len(selected_items) == 1:
+                item = selected_items[0]
+                self.insert_computation.emit(self.itemWidget(item)._name)
+
 
 class MinimalListWidget(QtWidgets.QListWidget):
 
     itemsDeleted = QtCore.pyqtSignal(list)
+    itemsPasted = QtCore.pyqtSignal()
 
     def __init__(self, *args, **kwargs):
 
@@ -348,6 +358,7 @@ class MinimalListWidget(QtWidgets.QListWidget):
 
     def keyPressEvent(self, event):
         key = event.key()
+        modifiers = event.modifiers()
         if key == QtCore.Qt.Key_Delete:
             selected_items = self.selectedItems()
             deleted = []
@@ -357,17 +368,35 @@ class MinimalListWidget(QtWidgets.QListWidget):
                 self.takeItem(row)
             if deleted:
                 self.itemsDeleted.emit(deleted)
+        elif key == QtCore.Qt.Key_C and modifiers == QtCore.Qt.ControlModifier:
+            try:
+                text = [item.text() for item in self.selectedItems()]
+                text = "\n".join(text)
+            except:
+                text = ""
+            QtWidgets.QApplication.instance().clipboard().setText(text)
+        elif key == QtCore.Qt.Key_V and modifiers == QtCore.Qt.ControlModifier:
+            lines = QtWidgets.QApplication.instance().clipboard().text().splitlines()
+            if lines:
+                try:
+                    self.addItems(lines)
+                    self.itemsPasted.emit()
+                except:
+                    pass
         else:
             super().keyPressEvent(event)
 
     def open_menu(self, position):
 
-        item = self.itemAt(position)
-        if item is None:
-            return
-
-        menu = QtWidgets.QMenu()
-        menu.addAction(self.tr("Delete (Del)"))
+        if self.count() == 0:
+            menu = QtWidgets.QMenu()
+            menu.addAction(self.tr("Paste names (Ctrl+V)"))
+        else:
+            menu = QtWidgets.QMenu()
+            menu.addAction(self.tr("Copy names (Ctrl+C)"))
+            menu.addAction(self.tr("Paste names (Ctrl+V)"))
+            menu.addSeparator()
+            menu.addAction(self.tr("Delete (Del)"))
 
         action = menu.exec_(self.viewport().mapToGlobal(position))
 
@@ -379,3 +408,13 @@ class MinimalListWidget(QtWidgets.QListWidget):
                 QtCore.QEvent.KeyPress, QtCore.Qt.Key_Delete, QtCore.Qt.NoModifier,
             )
             self.keyPressEvent(event)
+        elif action.text() == "Copy names (Ctrl+C)":
+            event = QtGui.QKeyEvent(
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_C, QtCore.Qt.ControlModifier,
+            )
+            self.keyPressEvent(event)
+        elif action.text() == "Paste names (Ctrl+V)":
+            event = QtGui.QKeyEvent(
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_V, QtCore.Qt.ControlModifier,
+            )
+            self.keyPressEvent(event)
