@@ -95,14 +95,31 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         open_group = QtWidgets.QActionGroup(self)
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/open.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+
         action = QtWidgets.QAction(icon, "Open", menu)
         action.triggered.connect(self.open)
         action.setShortcut(QtGui.QKeySequence("Ctrl+O"))
         open_group.addAction(action)
-        menu.addActions(open_group.actions())
+
         action = QtWidgets.QAction(icon, "Open folder", menu)
         action.triggered.connect(self.open_folder)
         open_group.addAction(action)
+
+        menu.addActions(open_group.actions())
+
+        menu.addSeparator()
+
+        open_group = QtWidgets.QActionGroup(self)
+        action = QtWidgets.QAction(icon, "Open configuration", menu)
+        action.triggered.connect(self.open_configuration)
+        open_group.addAction(action)
+
+        icon = QtGui.QIcon()
+        icon.addPixmap(QtGui.QPixmap(":/save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        action = QtWidgets.QAction(icon, "Save configuration", menu)
+        action.triggered.connect(self.save_configuration)
+        open_group.addAction(action)
+
         menu.addActions(open_group.actions())
 
         # mode_actions
@@ -217,6 +234,12 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         # plot option menu
         plot_actions = QtWidgets.QActionGroup(self)
 
+        icon = QtGui.QIcon()
+        icon.addPixmap(QtGui.QPixmap(":/fit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+        fullscreen = QtWidgets.QAction(icon, f"{'Fullscreen': <20}\tF8", menu)
+        fullscreen.triggered.connect(self.toggle_fullscreen)
+        fullscreen.setShortcut(QtCore.Qt.Key_F8)
+
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/fit.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
         action = QtWidgets.QAction(icon, f"{'Fit trace': <20}\tF", menu)
@@ -265,8 +288,13 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         action.setShortcut(QtCore.Qt.Key_O)
         plot_actions.addAction(action)
 
+        action = QtWidgets.QAction("{: <20}\tX".format("Zoom to range"), menu)
+        action.triggered.connect(partial(self.plot_action, key=QtCore.Qt.Key_X))
+        action.setShortcut(QtCore.Qt.Key_X)
+        plot_actions.addAction(action)
+
         action = QtWidgets.QAction("{: <20}\t.".format("Toggle dots"), menu)
-        action.triggered.connect(partial(self.toggle_dots, key=QtCore.Qt.Key_O))
+        action.triggered.connect(partial(self.toggle_dots, key=QtCore.Qt.Key_Period))
         action.setShortcut(QtCore.Qt.Key_Period)
         plot_actions.addAction(action)
 
@@ -405,6 +433,20 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         action.setShortcut(QtGui.QKeySequence("Shift+H"))
         subs.addAction(action)
 
+        action = QtWidgets.QAction(
+            "{: <20}\tShift+F".format("Toggle sub-plots frames"), menu
+        )
+        action.triggered.connect(self.toggle_frames)
+        action.setShortcut(QtGui.QKeySequence("Shift+F"))
+        subs.addAction(action)
+
+        action = QtWidgets.QAction(
+            "{: <20}\tShift+L".format("Toggle channel list"), menu
+        )
+        action.triggered.connect(self.toggle_channels_list)
+        action.setShortcut(QtGui.QKeySequence("Shift+L"))
+        subs.addAction(action)
+
         # cursors
         cursors_actions = QtWidgets.QActionGroup(self)
 
@@ -481,6 +523,8 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         cursors_actions.addAction(action)
 
         self.plot_menu = QtWidgets.QMenu("Plot", self.menubar)
+        self.plot_menu.addAction(fullscreen)
+        self.plot_menu.addSeparator()
         self.plot_menu.addActions(plot_actions.actions())
         self.plot_menu.addSeparator()
         self.plot_menu.addActions(cursors_actions.actions())
@@ -514,6 +558,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         self.setAcceptDrops(True)
 
         self.show()
+        self.fullscreen = None
 
     def help(self, event):
         webbrowser.open_new(r"http://asammdf.readthedocs.io/en/master/gui.html")
@@ -844,6 +889,7 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
             self.files.setTabToolTip(index, str(file_name))
             self.files.setCurrentIndex(index)
             widget.open_new_file.connect(self._open_file)
+            widget.full_screen_toggled.connect(self.toggle_fullscreen)
 
     def open_file(self, event):
         file_names, _ = QtWidgets.QFileDialog.getOpenFileNames(
@@ -991,6 +1037,9 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
                         ]
                         self.add_window((ret, names))
 
+        elif key == QtCore.Qt.Key_F8:
+            self.toggle_fullscreen()
+
         else:
             super().keyPressEvent(event)
 
@@ -1011,3 +1060,59 @@ class MainWindow(WithMDIArea, Ui_PyMDFMainWindow, QtWidgets.QMainWindow):
         QtWidgets.QMessageBox.information(
             self, "Measurement files used for comparison", "\n".join(info),
         )
+
+    def toggle_fullscreen(self):
+        if self.files.count() > 0 or self.fullscreen is not None:
+            if self.fullscreen is None:
+                index = self.files.currentIndex()
+                widget = self.files.widget(index)
+                if widget:
+                    widget.setParent(None)
+                    widget.showFullScreen()
+                    widget.autofit_sub_plots()
+                    self.fullscreen = widget, index
+            else:
+                widget, index = self.fullscreen
+                file_name = str(Path(widget.mdf.name).name)
+                self.files.insertTab(index, widget, file_name)
+                self.files.setTabToolTip(index, str(widget.mdf.name))
+                self.files.setCurrentIndex(index)
+                self.fullscreen = None
+                self.activateWindow()
+
+                widget.autofit_sub_plots()
+
+                self.with_dots = widget.with_dots
+                self._settings.setValue("dots", self.with_dots)
+
+                count = self.files.count()
+
+                for i in range(count):
+                    self.files.widget(i).set_line_style(with_dots=self.with_dots)
+
+    def toggle_frames(self, event=None):
+        count = self.files.count()
+
+        for i in range(count):
+            self.files.widget(i).toggle_frames()
+
+    def toggle_channels_list(self, event=None):
+        if self.stackedWidget.currentIndex() == 0:
+            widget = self.files.currentWidget()
+            event = QtGui.QKeyEvent(
+                QtCore.QEvent.KeyPress, QtCore.Qt.Key_L, QtCore.Qt.ShiftModifier
+            )
+            if widget:
+                widget.keyPressEvent(event)
+
+    def open_configuration(self, event=None):
+        if self.stackedWidget.currentIndex() == 0:
+            widget = self.files.currentWidget()
+            if widget:
+                widget.load_channel_list()
+
+    def save_configuration(self, event=None):
+        if self.stackedWidget.currentIndex() == 0:
+            widget = self.files.currentWidget()
+            if widget:
+                widget.save_channel_list()
