@@ -2,6 +2,8 @@
 from datetime import datetime
 from functools import partial
 import json
+import re
+import os
 from traceback import format_exc
 
 from natsort import natsorted
@@ -11,11 +13,12 @@ from PyQt5 import QtCore, QtGui, QtWidgets
 
 from ...blocks import v4_constants as v4c
 from ...blocks.utils import csv_bytearray2hex, extract_cncomment_xml, MdfException
+from ...signal import Signal
 from ..dialogs.channel_info import ChannelInfoDialog
 from ..utils import (
     add_children,
-    compute_signal,
     COLORS,
+    compute_signal,
     extract_mime_names,
     get_required_signals,
     HelperChannel,
@@ -100,7 +103,9 @@ class WithMDIArea:
     def __init__(self, *args, **kwargs):
         self._cursor_source = None
         self._region_source = None
+        self._splitter_source = None
         self._window_counter = 0
+        self._frameless_windows = False
 
     def add_new_channels(self, names, widget):
         try:
@@ -588,6 +593,11 @@ class WithMDIArea:
             w.setWindowTitle(f"Tabular {self._window_counter}")
             self._window_counter += 1
 
+        if self._frameless_windows:
+            w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
+
+        w.layout().setSpacing(1)
+
     def get_current_plot(self):
         mdi = self.mdi_area.activeSubWindow()
         if mdi is not None:
@@ -602,40 +612,135 @@ class WithMDIArea:
     def load_window(self, window_info):
 
         uuid = self.uuid
+        geometry = window_info.get("geometry", None)
 
         if window_info["type"] == "Numeric":
-            fmt = window_info["configuration"]["format"]
+            # patterns
+            pattern_info = window_info['configuration'].get('pattern', {})
+            if pattern_info:
+                required = set()
+                found_signals = []
+                fmt = "phys"
 
-            signals_ = [
-                (None, *self.mdf.whereis(name)[0])
-                for name in window_info["configuration"]["channels"]
-                if name in self.mdf
-            ]
+                pattern = pattern_info['pattern']
+                match_type = pattern_info["match_type"]
+                filter_value = pattern_info['filter_value']
+                filter_type = pattern_info['filter_type']
+                raw = pattern_info['raw']
 
-            if not signals_:
-                return
+                if match_type == "Wildcard":
+                    pattern = pattern.replace("*", "_WILDCARD_")
+                    pattern = re.escape(pattern)
+                    pattern = pattern.replace("_WILDCARD_", ".*")
 
-            signals = self.mdf.select(
-                signals_,
-                ignore_value2text_conversions=self.ignore_value2text_conversions,
-                copy_master=False,
-                validate=True,
-                raw=True,
-            )
+                try:
+                    pattern = re.compile(f"(?i){pattern}")
+                    matches = {
+                        name: entries[0]
+                        for name, entries in self.mdf.channels_db.items()
+                        if pattern.match(name)
+                    }
+                except:
+                    print(format_exc())
+                    signals = []
+                else:
 
-            for sig, sig_ in zip(signals, signals_):
-                sig.group_index = sig_[1]
-                sig.mdf_uuid = uuid
+                    psignals = self.mdf.select(
+                        list(matches),
+                        ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        copy_master=False,
+                        validate=True,
+                        raw=True,
+                    )
 
-            signals = [
-                sig
-                for sig in signals
-                if not sig.samples.dtype.names and len(sig.samples.shape) <= 1
-            ]
+                    if filter_type == 'Unspecified':
+                        keep = psignals
+                    else:
 
-            signals = natsorted(signals, key=lambda x: x.name)
+                        keep = []
+                        for i, (name, entry) in enumerate(matches.items()):
+                            sig = psignals[i]
+                            sig.mdf_uuid = uuid
+                            sig.group_index, sig.channel_index = entry
+
+                            size = len(sig)
+                            if not size:
+                                continue
+
+                            target = np.ones(size) * filter_value
+
+                            if not raw:
+                                samples = sig.physical().samples
+                            else:
+                                samples = sig.samples
+
+                            if filter_type == 'Contains':
+                                try:
+                                    if np.any(np.isclose(samples, target)):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                            elif filter_type == 'Do not contain':
+                                try:
+                                    if not np.allclose(samples, target):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                            else:
+                                try:
+                                    if np.allclose(samples, target):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                    signals = keep
+
+            else:
+
+                fmt = window_info["configuration"]["format"]
+                required = set(window_info["configuration"]["channels"])
+
+                signals_ = [
+                    (None, *self.mdf.whereis(name)[0])
+                    for name in window_info["configuration"]["channels"]
+                    if name in self.mdf
+                ]
+
+                if not signals_:
+                    return
+
+                signals = self.mdf.select(
+                    signals_,
+                    ignore_value2text_conversions=self.ignore_value2text_conversions,
+                    copy_master=False,
+                    validate=True,
+                    raw=True,
+                )
+
+                for sig, sig_ in zip(signals, signals_):
+                    sig.group_index = sig_[1]
+                    sig.mdf_uuid = uuid
+
+                signals = [
+                    sig
+                    for sig in signals
+                    if not sig.samples.dtype.names and len(sig.samples.shape) <= 1
+                ]
+
+                signals = natsorted(signals, key=lambda x: x.name)
+
+                found = set(sig.name for sig in signals)
+                not_found = [
+                    Signal([], [], name=name,) for name in sorted(required - found)
+                ]
+                uuid = os.urandom(6).hex()
+                for sig in not_found:
+                    sig.mdf_uuid = uuid
+                    sig.group_index = 0
+
+                signals.extend(not_found)
 
             numeric = Numeric(signals)
+            numeric.pattern = pattern_info
 
             if not self.subplots:
                 for mdi in self.mdi_area.subWindowList():
@@ -645,11 +750,11 @@ class WithMDIArea:
                 w.showMaximized()
             else:
                 w = self.mdi_area.addSubWindow(numeric)
+                w.show()
 
-                if len(self.mdi_area.subWindowList()) == 1:
-                    w.showMaximized()
+                if geometry:
+                    w.setGeometry(*geometry)
                 else:
-                    w.show()
                     self.mdi_area.tileSubWindows()
 
             if window_info["title"]:
@@ -681,97 +786,173 @@ class WithMDIArea:
             )
 
         elif window_info["type"] == "Plot":
+            # patterns
+            pattern_info = window_info['configuration'].get('pattern', {})
+            if pattern_info:
+                required = set()
+                found_signals = []
 
-            found_signals = [
-                channel
-                for channel in window_info["configuration"]["channels"]
-                if not channel["computed"] and channel["name"] in self.mdf
-            ]
+                pattern = pattern_info['pattern']
+                match_type = pattern_info["match_type"]
+                filter_value = pattern_info['filter_value']
+                filter_type = pattern_info['filter_type']
+                raw = pattern_info['raw']
 
-            measured_signals_ = [
-                (None, *self.mdf.whereis(channel["name"])[0])
-                for channel in found_signals
-            ]
-
-            measured_signals = {
-                sig.name: sig
-                for sig in self.mdf.select(
-                    measured_signals_,
-                    ignore_value2text_conversions=self.ignore_value2text_conversions,
-                    copy_master=False,
-                    validate=True,
-                    raw=True,
-                )
-            }
-
-            for signal, entry_info, channel in zip(measured_signals.values(), measured_signals_, found_signals):
-                signal.computed = False
-                signal.computation = {}
-                signal.color = channel["color"]
-                signal.group_index = entry_info[1]
-                signal.channel_index = entry_info[2]
-                signal.mdf_uuid = uuid
-
-            if measured_signals:
-                all_timebase = np.unique(
-                    np.concatenate(
-                        [sig.timestamps for sig in measured_signals.values()]
-                    )
-                )
-            else:
-                all_timebase = []
-
-            computed_signals_descriptions = [
-                channel
-                for channel in window_info["configuration"]["channels"]
-                if channel["computed"]
-            ]
-
-            required_channels = []
-            for ch in computed_signals_descriptions:
-                required_channels.extend(get_required_signals(ch))
-
-            required_channels = set(required_channels)
-            required_channels = [
-                (None, *self.mdf.whereis(channel)[0])
-                for channel in required_channels
-                if channel not in list(measured_signals) and channel in self.mdf
-            ]
-            required_channels = {
-                sig.name: sig
-                for sig in self.mdf.select(
-                    required_channels,
-                    ignore_value2text_conversions=self.ignore_value2text_conversions,
-                    copy_master=False,
-                )
-            }
-
-            required_channels.update(measured_signals)
-
-            computed_signals = {}
-
-            for channel in computed_signals_descriptions:
-                computation = channel["computation"]
+                if match_type == "Wildcard":
+                    pattern = pattern.replace("*", "_WILDCARD_")
+                    pattern = re.escape(pattern)
+                    pattern = pattern.replace("_WILDCARD_", ".*")
 
                 try:
+                    pattern = re.compile(f"(?i){pattern}")
+                    matches = [name for name in self.mdf.channels_db if pattern.match(name)]
+                except:
+                    print(format_exc())
+                    signals = []
+                else:
 
-                    signal = compute_signal(
-                        computation, required_channels, all_timebase
+                    psignals = self.mdf.select(
+                        matches,
+                        ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        copy_master=False,
+                        validate=True,
+                        raw=True,
                     )
+
+                    if filter_type == 'Unspecified':
+                        keep = psignals
+                    else:
+
+                        keep = []
+                        for sig in psignals:
+                            size = len(sig)
+                            if not size:
+                                continue
+
+                            target = np.ones(size) * filter_value
+
+
+                            if not raw:
+                                samples = sig.physical().samples
+                            else:
+                                samples = sig.samples
+
+                            if filter_type == 'Contains':
+                                try:
+                                    if np.any(np.isclose(samples, target)):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                            elif filter_type == 'Do not contain':
+                                try:
+                                    if not np.allclose(samples, target):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                            else:
+                                try:
+                                    if np.allclose(samples, target):
+                                        keep.append(sig)
+                                except:
+                                    continue
+                    signals = keep
+
+            else:
+
+                required = set(e["name"] for e in window_info["configuration"]["channels"])
+
+                found_signals = [
+                    channel
+                    for channel in window_info["configuration"]["channels"]
+                    if not channel["computed"] and channel["name"] in self.mdf
+                ]
+
+                measured_signals_ = [
+                    (None, *self.mdf.whereis(channel["name"])[0])
+                    for channel in found_signals
+                ]
+
+                measured_signals = {
+                    sig.name: sig
+                    for sig in self.mdf.select(
+                        measured_signals_,
+                        ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        copy_master=False,
+                        validate=True,
+                        raw=True,
+                    )
+                }
+
+                for signal, entry_info, channel in zip(
+                    measured_signals.values(), measured_signals_, found_signals
+                ):
+                    signal.computed = False
+                    signal.computation = {}
                     signal.color = channel["color"]
-                    signal.computed = True
-                    signal.computation = channel["computation"]
-                    signal.name = channel["name"]
-                    signal.unit = channel["unit"]
-                    signal.group_index = -1
-                    signal.channel_index = -1
+                    signal.group_index = entry_info[1]
+                    signal.channel_index = entry_info[2]
                     signal.mdf_uuid = uuid
 
-                    computed_signals[signal.name] = signal
-                except:
-                    pass
+                if measured_signals:
+                    all_timebase = np.unique(
+                        np.concatenate(
+                            [sig.timestamps for sig in measured_signals.values()]
+                        )
+                    )
+                else:
+                    all_timebase = []
 
-            signals = list(measured_signals.values()) + list(computed_signals.values())
+                computed_signals_descriptions = [
+                    channel
+                    for channel in window_info["configuration"]["channels"]
+                    if channel["computed"]
+                ]
+
+                required_channels = []
+                for ch in computed_signals_descriptions:
+                    required_channels.extend(get_required_signals(ch))
+
+                required_channels = set(required_channels)
+                required_channels = [
+                    (None, *self.mdf.whereis(channel)[0])
+                    for channel in required_channels
+                    if channel not in list(measured_signals) and channel in self.mdf
+                ]
+                required_channels = {
+                    sig.name: sig
+                    for sig in self.mdf.select(
+                        required_channels,
+                        ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        copy_master=False,
+                    )
+                }
+
+                required_channels.update(measured_signals)
+
+                computed_signals = {}
+
+                for channel in computed_signals_descriptions:
+                    computation = channel["computation"]
+
+                    try:
+
+                        signal = compute_signal(
+                            computation, required_channels, all_timebase
+                        )
+                        signal.color = channel["color"]
+                        signal.computed = True
+                        signal.computation = channel["computation"]
+                        signal.name = channel["name"]
+                        signal.unit = channel["unit"]
+                        signal.group_index = -1
+                        signal.channel_index = -1
+                        signal.mdf_uuid = uuid
+
+                        computed_signals[signal.name] = signal
+                    except:
+                        pass
+
+                signals = list(measured_signals.values()) + list(computed_signals.values())
 
             signals = [
                 sig
@@ -829,7 +1010,19 @@ class WithMDIArea:
                 events = []
                 origin = self.files.widget(0).mdf.start_time
 
-            plot = Plot([], self.with_dots, events=events, origin=origin)
+            found = set(sig.name for sig in signals)
+            not_found = [
+                Signal([], [], name=name,) for name in sorted(required - found)
+            ]
+            uuid = os.urandom(6).hex()
+            for sig in not_found:
+                sig.mdf_uuid = uuid
+                sig.group_index = 0
+
+            signals.extend(not_found)
+
+            plot = Plot([], with_dots=self.with_dots, events=events, origin=origin)
+            plot.pattern = pattern_info
 
             if not self.subplots:
                 for mdi in self.mdi_area.subWindowList():
@@ -840,15 +1033,21 @@ class WithMDIArea:
             else:
                 w = self.mdi_area.addSubWindow(plot)
 
-                if len(self.mdi_area.subWindowList()) == 1:
-                    w.showMaximized()
+                w.show()
+
+                if geometry:
+                    w.setGeometry(*geometry)
                 else:
-                    w.show()
                     self.mdi_area.tileSubWindows()
 
             plot.hide()
 
             plot.add_new_channels(signals)
+            for i, sig in enumerate(not_found, len(found)):
+                item = plot.channel_selection.item(i)
+                widget = plot.channel_selection.itemWidget(item)
+                widget.does_not_exist()
+
             needs_update = False
             for channel, sig in zip(found_signals, plot.plot.signals):
                 if "mode" in channel:
@@ -895,42 +1094,134 @@ class WithMDIArea:
                 wid = plot.channel_selection.itemWidget(plot.channel_selection.item(i))
                 name = wid._name
 
-                description = descriptions[name]
+                description = descriptions.get(name, None)
+                if description is not None:
 
-                wid.set_fmt(description["fmt"])
-                wid.set_precision(description["precision"])
-                wid.ranges = {
-                    (range["start"], range["stop"]): range["color"]
-                    for range in description["ranges"]
-                }
-                wid.ylink.setCheckState(
-                    QtCore.Qt.Checked
-                    if description["common_axis"]
-                    else QtCore.Qt.Unchecked
-                )
-                wid.display.setCheckState(
-                    QtCore.Qt.Checked if description["enabled"] else QtCore.Qt.Unchecked
-                )
+                    wid.set_fmt(description["fmt"])
+                    wid.set_precision(description["precision"])
+                    wid.ranges = {
+                        (range["start"], range["stop"]): range["color"]
+                        for range in description["ranges"]
+                    }
+                    wid.ylink.setCheckState(
+                        QtCore.Qt.Checked
+                        if description["common_axis"]
+                        else QtCore.Qt.Unchecked
+                    )
+                    wid.display.setCheckState(
+                        QtCore.Qt.Checked if description["enabled"] else QtCore.Qt.Unchecked
+                    )
+                elif pattern_info:
+                    wid.ranges = pattern_info['ranges']
 
             self.set_subplots_link(self.subplots_link)
 
+            plot.splitter.setContentsMargins(1, 1, 1, 1)
+            plot.setContentsMargins(1, 1, 1, 1)
+
         elif window_info["type"] == "Tabular":
+            # patterns
+            pattern_info = window_info['configuration'].get('pattern', {})
+            if pattern_info:
+                required = set()
+                found_signals = []
 
-            signals_ = [
-                (None, *self.mdf.whereis(name)[0])
-                for name in window_info["configuration"]["channels"]
-                if name in self.mdf
-            ]
+                pattern = pattern_info['pattern']
+                match_type = pattern_info["match_type"]
+                filter_value = pattern_info['filter_value']
+                filter_type = pattern_info['filter_type']
+                raw = pattern_info['raw']
 
-            if not signals_:
-                return
+                if match_type == "Wildcard":
+                    pattern = pattern.replace("*", "_WILDCARD_")
+                    pattern = re.escape(pattern)
+                    pattern = pattern.replace("_WILDCARD_", ".*")
+
+                try:
+                    pattern = re.compile(f"(?i){pattern}")
+                    matches = {
+                        name: entries[0]
+                        for name, entries in self.mdf.channels_db.items()
+                        if pattern.match(name)
+                    }
+                except:
+                    print(format_exc())
+                    signals_ = []
+                else:
+
+                    psignals = self.mdf.select(
+                        list(matches),
+                        ignore_value2text_conversions=self.ignore_value2text_conversions,
+                        copy_master=False,
+                        validate=True,
+                        raw=True,
+                    )
+
+                    if filter_type == 'Unspecified':
+                        keep = list(matches)
+                    else:
+
+                        keep = []
+                        for i, (name, entry) in enumerate(matches.items()):
+                            sig = psignals[i]
+                            size = len(sig)
+                            if not size:
+                                continue
+
+                            target = np.ones(size) * filter_value
+
+                            if not raw:
+                                samples = sig.physical().samples
+                            else:
+                                samples = sig.samples
+
+                            if filter_type == 'Contains':
+                                try:
+                                    if np.any(np.isclose(samples, target)):
+                                        keep.append(name)
+                                except:
+                                    continue
+                            elif filter_type == 'Do not contain':
+                                try:
+                                    if not np.allclose(samples, target):
+                                        keep.append(name)
+                                except:
+                                    continue
+                            else:
+                                try:
+                                    if np.allclose(samples, target):
+                                        keep.append(name)
+                                except:
+                                    continue
+                    signals_ = keep
+
+            else:
+                required = set(window_info["configuration"]["channels"])
+
+                signals_ = [
+                    (None, *self.mdf.whereis(name)[0])
+                    for name in window_info["configuration"]["channels"]
+                    if name in self.mdf
+                ]
+
+                if not signals_:
+                    return
 
             signals = self.mdf.to_dataframe(
                 channels=signals_,
                 ignore_value2text_conversions=self.ignore_value2text_conversions,
             )
 
+            found = set(signals.columns)
+            dim = len(signals.index)
+
+            for name in sorted(required - found):
+                vals = np.empty(dim)
+                vals.fill(np.NaN)
+                signals[name] = pd.Series(vals, index=signals.index)
+
             tabular = Tabular(signals, start=self.mdf.header.start_time.timestamp())
+            tabular.pattern = pattern_info
 
             if not self.subplots:
                 for mdi in self.mdi_area.subWindowList():
@@ -941,10 +1232,11 @@ class WithMDIArea:
             else:
                 w = self.mdi_area.addSubWindow(tabular)
 
-                if len(self.mdi_area.subWindowList()) == 1:
-                    w.showMaximized()
+                w.show()
+
+                if geometry:
+                    w.setGeometry(*geometry)
                 else:
-                    w.show()
                     self.mdi_area.tileSubWindows()
 
             if window_info["title"]:
@@ -998,20 +1290,34 @@ class WithMDIArea:
                 if ok and name:
                     mdi.setWindowTitle(name)
 
+            def set_pattern(mdi):
+                pass
+
             action = QtWidgets.QAction("Set title", menu)
             action.triggered.connect(partial(set_title, w))
             before = menu.actions()[0]
             menu.insertAction(before, action)
             w.setSystemMenu(menu)
 
+        if self._frameless_windows:
+            w.setWindowFlags(w.windowFlags() | QtCore.Qt.FramelessWindowHint)
+
+        if pattern_info:
+            icon = QtGui.QIcon()
+            icon.addPixmap(QtGui.QPixmap(":/filter.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
+            w.setWindowIcon(icon)
+
+        w.layout().setSpacing(1)
+
     def set_line_style(self, with_dots=None):
-        if with_dots is not None:
+        if with_dots is None:
+            with_dots = not self.with_dots
 
-            self.with_dots = with_dots
+        self.with_dots = with_dots
 
-            current_plot = self.get_current_plot()
-            if current_plot:
-                current_plot.plot.update_lines(with_dots=with_dots)
+        current_plot = self.get_current_plot()
+        if current_plot:
+            current_plot.plot.update_lines(with_dots=with_dots)
 
     def set_subplots(self, option):
         self.subplots = option
@@ -1031,6 +1337,7 @@ class WithMDIArea:
                     widget.cursor_removed_signal.connect(self.remove_cursor)
                     widget.region_removed_signal.connect(self.remove_region)
                     widget.region_moved_signal.connect(self.set_region)
+                    widget.splitter_moved.connect(self.set_splitter)
                 elif isinstance(widget, Numeric):
                     widget.timestamp_changed_signal.connect(self.set_cursor)
         else:
@@ -1054,6 +1361,10 @@ class WithMDIArea:
                         widget.region_modified_signal.disconnect(self.set_region)
                     except:
                         pass
+                    try:
+                        widget.splitter_moved.disconnect(self.set_splitter)
+                    except:
+                        pass
                 elif isinstance(widget, Numeric):
                     try:
                         widget.timestamp_changed_signal.disconnect(self.set_cursor)
@@ -1094,6 +1405,21 @@ class WithMDIArea:
                     wid.plot.region.setRegion(region)
             self._region_source = None
 
+    def set_splitter(self, widget, selection_width):
+        if self._splitter_source is None:
+            self._splitter_source = widget
+            for mdi in self.mdi_area.subWindowList():
+                wid = mdi.widget()
+                if isinstance(wid, Plot) and wid is not widget:
+                    if selection_width is not None:
+                        total_size = sum(wid.splitter.sizes())
+                        if total_size > selection_width:
+                            wid.splitter.setSizes(
+                                [selection_width, total_size - selection_width]
+                            )
+
+            self._splitter_source = None
+
     def remove_cursor(self, widget):
         if self._cursor_source is None:
             self._cursor_source = widget
