@@ -29,9 +29,11 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
         self.setupUi(self)
         for sig in signals:
             sig.timestamps = np.around(sig.timestamps, 9)
-        self.signals = {sig.name: sig for sig in signals}
+        self.signals = {}
         self._min = self._max = 0
         self.format = "phys"
+        self.add_new_channels(signals)
+        self.pattern = {}
 
         self.timestamp.valueChanged.connect(self._timestamp_changed)
         self.timestamp_slider.valueChanged.connect(self._timestamp_slider_changed)
@@ -60,6 +62,7 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
         self._min = float("inf")
         self._max = -float("inf")
         items = []
+
         for sig in self.signals.values():
             sig.kind = sig.samples.dtype.kind
             size = len(sig)
@@ -197,9 +200,18 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
         self.channels.sortByColumn(index, order)
 
     def add_new_channels(self, channels):
+        invalid = []
         for sig in channels:
             if sig:
+                if np.any(np.diff(sig.timestamps) < 0):
+                    invalid.append(sig.name)
                 self.signals[sig.name] = sig
+        if invalid:
+            QtWidgets.QMessageBox.warning(
+                self,
+                "The following channels do not have monotonous increasing time stamps:",
+                f"The following channels do not have monotonous increasing time stamps:\n{', '.join(invalid)}",
+            )
         self.build()
 
     def keyPressEvent(self, event):
@@ -238,7 +250,8 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
 
         config = {
             "format": self.format,
-            "channels": channels,
+            "channels": channels if not self.pattern else [],
+            "pattern": self.pattern,
         }
 
         return config
@@ -249,7 +262,7 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
             or not self.target.text().strip()
             or not self.pattern.text().strip()
         ):
-            self.match.setText(f"invalid input values")
+            self.match.setText("invalid input values")
             return
 
         operator = self.op.currentText()
@@ -262,13 +275,13 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
         matches = [name for name in self.signals if pattern.match(name)]
 
         if not matches:
-            self.match.setText(f"the pattern does not match any channel name")
+            self.match.setText("the pattern does not match any channel name")
             return
 
         try:
             target = float(self.target.text().strip())
         except:
-            self.match.setText(f"the target must a numeric value")
+            self.match.setText("the target must a numeric value")
         else:
 
             if target.is_integer():
@@ -301,7 +314,7 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
                 self.timestamp.setValue(timestamp)
                 self.match.setText(f"condition found for {signal_name}")
             else:
-                self.match.setText(f"condition not found")
+                self.match.setText("condition not found")
 
     def search_backward(self):
         if (
@@ -309,7 +322,7 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
             or not self.target.text().strip()
             or not self.pattern.text().strip()
         ):
-            self.match.setText(f"invalid input values")
+            self.match.setText("invalid input values")
             return
 
         operator = self.op.currentText()
@@ -322,7 +335,7 @@ class Numeric(Ui_NumericDisplay, QtWidgets.QWidget):
         matches = [name for name in self.signals if pattern.match(name)]
 
         if not matches:
-            self.match.setText(f"the pattern does not match any channel name")
+            self.match.setText("the pattern does not match any channel name")
             return
 
         try:
