@@ -6,7 +6,6 @@ import os
 from pathlib import Path
 from struct import unpack
 from time import perf_counter
-from uuid import uuid4
 
 import numpy as np
 from PyQt5 import QtCore, QtGui, QtWidgets
@@ -26,13 +25,9 @@ from .list_item import ListItem
 
 bin_ = bin
 
-
 HERE = Path(__file__).resolve().parent
 
 
-# pg.setConfigOption("useOpenGL", True)
-
-
 if not hasattr(pg.InfiniteLine, "addMarker"):
     logger = logging.getLogger("asammdf")
     message = (
@@ -64,8 +59,8 @@ class PlotSignal(Signal):
             encoding=signal.encoding,
         )
 
-        self.uuid = getattr(signal, "uuid", uuid4())
-        self.mdf_uuid = getattr(signal, "mdf_uuid", uuid4())
+        self.uuid = getattr(signal, "uuid", os.urandom(6).hex())
+        self.mdf_uuid = getattr(signal, "mdf_uuid", os.urandom(6).hex())
 
         self.group_index = getattr(signal, "group_index", -1)
         self.channel_index = getattr(signal, "channel_index", -1)
@@ -563,7 +558,6 @@ class PlotSignal(Signal):
         if self.trim_info == trim_info:
             return
 
-
         self.trim_info = trim_info
         sig = self
         dim = len(sig.timestamps)
@@ -694,11 +688,13 @@ class Plot(QtWidgets.QWidget):
     region_moved_signal = QtCore.pyqtSignal(object, list)
     region_removed_signal = QtCore.pyqtSignal(object)
     show_properties = QtCore.pyqtSignal(list)
+    splitter_moved = QtCore.pyqtSignal(object, int)
 
     def __init__(self, signals, with_dots=False, origin=None, *args, **kwargs):
         events = kwargs.pop("events", None)
         super().__init__(*args, **kwargs)
         self.setContentsMargins(0, 0, 0, 0)
+        self.pattern = {}
 
         self.info_uuid = None
 
@@ -708,6 +704,8 @@ class Plot(QtWidgets.QWidget):
         self._can_switch_mode = True
 
         main_layout = QtWidgets.QVBoxLayout(self)
+        main_layout.setSpacing(1)
+        main_layout.setContentsMargins(1, 1, 1, 1)
         # self.setLayout(main_layout)
 
         vbox = QtWidgets.QVBoxLayout()
@@ -731,7 +729,9 @@ class Plot(QtWidgets.QWidget):
         self.splitter.addWidget(widget)
         self.splitter.setOpaqueResize(False)
 
-        self.plot = _Plot(with_dots=with_dots, parent=self, events=events, origin=origin)
+        self.plot = _Plot(
+            with_dots=with_dots, parent=self, events=events, origin=origin
+        )
 
         self.plot.range_modified.connect(self.range_modified)
         self.plot.range_removed.connect(self.range_removed)
@@ -755,6 +755,8 @@ class Plot(QtWidgets.QWidget):
         self.splitter.setStretchFactor(1, 2)
         self.splitter.setStretchFactor(2, 0)
 
+        self.splitter.splitterMoved.connect(self.set_splitter)
+
         self.plot.add_channels_request.connect(self.add_channels_request)
         self.setAcceptDrops(True)
 
@@ -771,6 +773,7 @@ class Plot(QtWidgets.QWidget):
         self.channel_selection.add_channels_request.connect(self.add_channels_request)
         self.channel_selection.set_time_offset.connect(self.plot.set_time_offset)
         self.channel_selection.show_properties.connect(self._show_properties)
+        self.channel_selection.insert_computation.connect(self.plot.insert_computation)
 
         self.keyboard_events = (
             set(
@@ -1278,7 +1281,7 @@ class Plot(QtWidgets.QWidget):
     def add_new_channels(self, channels):
 
         for sig in channels:
-            sig.uuid = uuid4()
+            sig.uuid = os.urandom(6).hex()
 
         invalid = []
 
@@ -1323,6 +1326,18 @@ class Plot(QtWidgets.QWidget):
 
         channels = self.plot.add_new_channels(channels)
 
+        count = self.channel_selection.count()
+        if count:
+            for i in range(count):
+                wid = self.channel_selection.itemWidget(self.channel_selection.item(i))
+                if wid.ylink.checkState() == QtCore.Qt.Unchecked:
+                    enforce_y_axis = False
+                    break
+            else:
+                enforce_y_axis = True
+        else:
+            enforce_y_axis = False
+
         for sig in channels:
 
             item = ListItem(
@@ -1351,6 +1366,8 @@ class Plot(QtWidgets.QWidget):
             it.color_changed.connect(self.plot.set_color)
             it.enable_changed.connect(self.plot.set_signal_enable)
             it.ylink_changed.connect(self.plot.set_common_axis)
+            if enforce_y_axis:
+                it.ylink.setCheckState(QtCore.Qt.Checked)
             it.individual_axis_changed.connect(self.plot.set_individual_axis)
 
             self.info_uuid = sig.uuid
@@ -1363,7 +1380,7 @@ class Plot(QtWidgets.QWidget):
             channel = {}
             item = self.channel_selection.itemWidget(self.channel_selection.item(i))
 
-            sig, _ = self.plot.signal_by_uuid(item.uuid)
+            sig, idx = self.plot.signal_by_uuid(item.uuid)
 
             channel["name"] = sig.name
             channel["unit"] = sig.unit
@@ -1386,10 +1403,17 @@ class Plot(QtWidgets.QWidget):
             if sig.computed:
                 channel["computation"] = sig.computation
 
+            view = self.plot.view_boxes[idx]
+            channel["view_box"] = [
+                [float(e) for e in axis] for axis in view.viewRange()
+            ]
+            channel["mdf_uuid"] = str(sig.mdf_uuid)
+
             channels.append(channel)
 
         config = {
-            "channels": channels,
+            "channels": channels if not self.pattern else [],
+            "pattern": self.pattern,
         }
 
         return config
@@ -1427,6 +1451,9 @@ class Plot(QtWidgets.QWidget):
                     [sig.group_index, sig.channel_index, sig.mdf_uuid]
                 )
 
+    def set_splitter(self, pos, index):
+        self.splitter_moved.emit(self, pos)
+
 
 class _Plot(pg.PlotWidget):
     cursor_moved = QtCore.pyqtSignal()
@@ -1488,12 +1515,12 @@ class _Plot(pg.PlotWidget):
         self.plot_item = self.plotItem
         self.plot_item.hideAxis("left")
         self.plot_item.hideAxis("bottom")
+        self.plotItem.showGrid(x=False, y=False)
         self.layout = self.plot_item.layout
         self.scene_ = self.plot_item.scene()
         self.scene_.sigMouseClicked.connect(self._clicked)
         self.viewbox = self.plot_item.vb
 
-
         self.common_axis_items = set()
         self.common_axis_label = ""
         self.common_viewbox = pg.ViewBox(enableMenu=True)
@@ -1672,7 +1699,7 @@ class _Plot(pg.PlotWidget):
                             if curve.opts["pen"].style() != style:
                                 curve.opts["pen"].setStyle(style)
                             curve.update()
-                            curve.sigPlotChanged.emit(curve)
+                #                            curve.sigPlotChanged.emit(curve)
 
                 if sig.enable:
                     curve.show()
@@ -1687,6 +1714,10 @@ class _Plot(pg.PlotWidget):
             self.curves[index].setSymbolPen(color)
             self.curves[index].setSymbolBrush(color)
 
+            if self.signals[index].individual_axis:
+                self.axes[index].setPen(color)
+                self.axes[index].setTextPen(color)
+
         if uuid == self.current_uuid:
             self.y_axis.setPen(color)
             self.y_axis.setTextPen(color)
@@ -1740,11 +1771,14 @@ class _Plot(pg.PlotWidget):
             self.view_boxes[index].setXLink(None)
             self.axes[index].hide()
 
-            self._timebase_db[id(sig.timestamps)].remove(uuid)
+            try:
+                self._timebase_db[id(sig.timestamps)].remove(uuid)
 
-            if len(self._timebase_db[id(sig.timestamps)]) == 0:
-                del self._timebase_db[id(sig.timestamps)]
-                self._compute_all_timebase()
+                if len(self._timebase_db[id(sig.timestamps)]) == 0:
+                    del self._timebase_db[id(sig.timestamps)]
+                    self._compute_all_timebase()
+            except:
+                pass
 
         if self.cursor1:
             self.cursor_move_finished.emit()
@@ -1803,6 +1837,14 @@ class _Plot(pg.PlotWidget):
                 else:
                     self.region_lock = None
 
+            elif key == QtCore.Qt.Key_X and modifier == QtCore.Qt.NoModifier:
+                if self.region is not None:
+                    self.viewbox.setXRange(*self.region.getRegion(), padding=0)
+                    event_ = QtGui.QKeyEvent(
+                        QtCore.QEvent.KeyPress, QtCore.Qt.Key_R, QtCore.Qt.NoModifier
+                    )
+                    self.keyPressEvent(event_)
+
             elif key == QtCore.Qt.Key_F and modifier == QtCore.Qt.NoModifier:
                 if self.common_axis_items:
                     if any(
@@ -1862,10 +1904,15 @@ class _Plot(pg.PlotWidget):
                     self.cursor_moved.emit()
 
             elif key == QtCore.Qt.Key_G and modifier == QtCore.Qt.NoModifier:
-                if self.plotItem.ctrl.yGridCheck.isChecked():
-                    self.showGrid(x=True, y=False)
+                y = self.plotItem.ctrl.yGridCheck.isChecked()
+                x = self.plotItem.ctrl.xGridCheck.isChecked()
+
+                if x and y:
+                    self.plotItem.showGrid(x=False, y=False)
+                elif x:
+                    self.plotItem.showGrid(x=True, y=True)
                 else:
-                    self.showGrid(x=True, y=True)
+                    self.plotItem.showGrid(x=True, y=False)
 
             elif (
                 key in (QtCore.Qt.Key_I, QtCore.Qt.Key_O)
@@ -2105,16 +2152,7 @@ class _Plot(pg.PlotWidget):
                         self.cursor_moved.emit()
 
             elif key == QtCore.Qt.Key_Insert and modifier == QtCore.Qt.NoModifier:
-                dlg = DefineChannel(self.signals, self.all_timebase, self)
-                dlg.setModal(True)
-                dlg.exec_()
-                sig = dlg.result
-
-                if sig is not None:
-                    sig.uuid = uuid4()
-                    sig.mdf_uuid = uuid4()
-                    self.add_new_channels([sig], computed=True)
-                    self.computation_channel_inserted.emit()
+                self.insert_computation()
 
             else:
                 self.parent().keyPressEvent(event)
@@ -2247,7 +2285,8 @@ class _Plot(pg.PlotWidget):
         trim_info = start, stop, width
 
         channels = [
-            PlotSignal(sig, i, trim_info=trim_info) for i, sig in enumerate(channels, len(self.signals))
+            PlotSignal(sig, i, trim_info=trim_info)
+            for i, sig in enumerate(channels, len(self.signals))
         ]
 
         for sig in channels:
@@ -2255,10 +2294,7 @@ class _Plot(pg.PlotWidget):
             uuids.add(sig.uuid)
         self.signals.extend(channels)
 
-        self._uuid_map = {
-            sig.uuid: (sig, i)
-            for i, sig in enumerate(self.signals)
-        }
+        self._uuid_map = {sig.uuid: (sig, i) for i, sig in enumerate(self.signals)}
 
         self._compute_all_timebase()
 
@@ -2283,14 +2319,14 @@ class _Plot(pg.PlotWidget):
             view_box.disableAutoRange()
 
             axis.linkToView(view_box)
-#            if len(sig.name) <= 32:
-#                axis.labelText = sig.name
-#            else:
-#                axis.labelText = f"{sig.name[:29]}..."
-#            axis.labelUnits = sig.unit
-#            axis.labelStyle = {"color": color}
-#
-#            axis.setLabel(axis.labelText, sig.unit, color=color)
+            #            if len(sig.name) <= 32:
+            #                axis.labelText = sig.name
+            #            else:
+            #                axis.labelText = f"{sig.name[:29]}..."
+            #            axis.labelUnits = sig.unit
+            #            axis.labelStyle = {"color": color}
+            #
+            #            axis.setLabel(axis.labelText, sig.unit, color=color)
 
             self.layout.addItem(axis, 2, self._axes_layout_pos)
             self._axes_layout_pos += 1
@@ -2321,8 +2357,8 @@ class _Plot(pg.PlotWidget):
                 view_box.setYRange(sig.min, sig.max, padding=0, update=True)
 
             view_box.setGeometry(geometry)
-#            (start, stop), _ = self.viewbox.viewRange()
-#            view_box.setXRange(start, stop, padding=0, update=True)
+            #            (start, stop), _ = self.viewbox.viewRange()
+            #            view_box.setXRange(start, stop, padding=0, update=True)
 
             self.axes.append(axis)
             axis.hide()
@@ -2419,10 +2455,7 @@ class _Plot(pg.PlotWidget):
 
         uuids = [sig.uuid for sig in self.signals]
 
-        self._uuid_map = {
-            sig.uuid: (sig, i)
-            for i, sig in enumerate(self.signals)
-        }
+        self._uuid_map = {sig.uuid: (sig, i) for i, sig in enumerate(self.signals)}
 
         if uuids:
             if self.current_uuid in uuids:
@@ -2471,3 +2504,15 @@ class _Plot(pg.PlotWidget):
         self._compute_all_timebase()
 
         self.xrange_changed_handle()
+
+    def insert_computation(self, name=""):
+        dlg = DefineChannel(self.signals, self.all_timebase, name, self)
+        dlg.setModal(True)
+        dlg.exec_()
+        sig = dlg.result
+
+        if sig is not None:
+            sig.uuid = os.urandom(6).hex()
+            sig.mdf_uuid = os.urandom(6).hex()
+            self.add_new_channels([sig], computed=True)
+            self.computation_channel_inserted.emit()
