@@ -48,7 +48,7 @@ class NumericTreeWidget(QtWidgets.QTreeWidget):
             and event.modifiers() == QtCore.Qt.NoModifier
         ):
             selected = reversed(self.selectedItems())
-            names = [item.text(0) for item in selected]
+            names = [(item.mdf_uuid, item.text(0)) for item in selected]
             for item in selected:
                 if item.parent() is None:
                     index = self.indexFromItem(item).row()
@@ -81,7 +81,7 @@ class NumericTreeWidget(QtWidgets.QTreeWidget):
 
             data.append(
                 pack(
-                    f"<36s3q{len(info)}s",
+                    f"<12s3q{len(info)}s",
                     str(item.mdf_uuid).encode("ascii"),
                     entry[0],
                     entry[1],
