@@ -101,7 +101,7 @@ class TestMDF4(unittest.TestCase):
         )
 
         with MDF(outfile) as attachment_mdf:
-            data, filename = attachment_mdf.extract_attachment(index=0)
+            data, filename, md5_sum = attachment_mdf.extract_attachment(index=0)
             self.assertEqual(data, original_data)
             self.assertEqual(filename, Path("bin.bin"))
 
@@ -125,7 +125,7 @@ class TestMDF4(unittest.TestCase):
         )
 
         with MDF(outfile) as attachment_mdf:
-            data, filename = attachment_mdf.extract_attachment(index=0)
+            data, filename, md5_sum = attachment_mdf.extract_attachment(index=0)
             self.assertEqual(data, original_data)
             self.assertEqual(filename, Path(original_file_name))
 
